@@ -5,11 +5,10 @@ use namespace::autoclean;
 use Carp qw( croak );
 use File::Spec ();
 use Moo::Role;
-use Parallel::Iterator qw(iterate_as_array);
 with 'Archive::BagIt::Role::Plugin';
 with 'Archive::BagIt::Role::Portability';
 # ABSTRACT: A role that handles all manifest files for a specific Algorithm
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.081'; # VERSION
 
 has 'algorithm' => (
     is => 'rw',
@@ -134,15 +133,10 @@ sub _fill_digest_hashref {
 # $tmp->{filename} = $filename;
 sub calc_digests {
     my ($self, $bagit, $filenames_ref) = @_;
-    # Serial code is:
-    ## my @digest_hashes2 = map {
-    ##        $self->_fill_digest_hashref($bagit,  $_);
-    ##    } @{$filenames_ref};
-    # If the parallel version fails, go back to serial version
-    my @digest_hashes = iterate_as_array(sub {
-        my ($index, $file) = @_;
-        return $self->_fill_digest_hashref($bagit, $file);
-    }, $filenames_ref);
+    #the parallel version fails with Parallel::Iterator, therefore back to serial version
+    my @digest_hashes = map {
+        $self->_fill_digest_hashref($bagit, $_);
+    } @{ $filenames_ref };
     return \@digest_hashes;
 }
 
@@ -320,7 +314,7 @@ Archive::BagIt::Role::Manifest - A role that handles all manifest files for a sp
 
 =head1 VERSION
 
-version 0.08
+version 0.081
 
 =head2 calc_digests($bagit, $filenames_ref, $opts)
 
